#
# spec file for package postgrey
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           postgrey
Version:        1.37
Release:        bp156.4.2
Summary:        Postfix greylisting policy server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            http://postgrey.schweikert.ch/
Source0:        http://postgrey.schweikert.ch/pub/%{name}-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.sysconfig
Source3:        %{name}.README.SUSE
# http://hg.schweikert.ch/dispatch.fcgi/postgrey-1.x/raw-file/ca06ef218498/postgrey_clients_dump
Source5:        postgrey_clients_dump
Source6:        %{name}.service
Source7:        %{name}_daily_greylist.service
Source8:        %{name}_daily_greylist.timer
Source9:        %{name}_daily_greylist.sh
# PATCH-FIX-OPENSUSE -- Adapt default config and documentation to pathnames for openSUSE
# /etc/postfix => /etc/postgrey
# /var/spool/postfix/postgrey => /var/lib/postgrey
Patch0:         %{name}-%{version}-config.patch
# PATCH-FIX-OPENSUSE -- run postgrey under the same groupid as postfix: postfix
Patch1:         %{name}-groupid.patch
# PATCH-FIX-OPENSUSE -- patch SOURCE5 to run under openSUSE
Patch2:         postgrey_clients_dump.patch
%if 0%{?suse_version} < 1210
# PATCH-FIX-OPENSUSE -- revert process name changes from 1.35
# startproc will return 7 without
Patch3:         postgrey_process_name.patch
%endif
BuildRequires:  postfix
Requires:       perl >= 5.6.0
Requires:       perl-BerkeleyDB
Requires:       perl-IO-Multiplex
Requires:       perl-Net-DNS
Requires:       perl-Net-Server
Requires:       perl-NetAddr-IP
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if 0%{?suse_version}
Suggests:       cron
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(systemd)
%systemd_ordering
%endif
Requires(post): %fillup_prereq
%endif
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif

%description
Postgrey is a Postfix policy server implementing greylisting. When a
request for delivery of a mail is received by Postfix via SMTP, the
triplet CLIENT_IP / SENDER / RECIPIENT is built. If it is the first
time that this triplet is seen, or if the triplet was first seen less
than 5 minutes, then the mail gets rejected with a temporary error.
Hopefully spammers or viruses will not try again later, as it is
however required per RFC.

The following features compared with greylist.pl from Postfix 2.1.1 are
new: Safe database, automatic maintenance, whitelists, lookup by
subnet, auto-whitelisting of clients, only Berkeley DB and no large
mysql nor postgresql DB needed.

%prep
%setup -q
test -d examples || mkdir examples
cp %{SOURCE5} examples/
test -d timer || mkdir timer
cp -a %{SOURCE7} timer/
cp -a %{SOURCE8} timer/
cp -a %{SOURCE9} timer/
%patch0
%patch1
%patch2
%if 0%{?suse_version} < 1210
%patch3
%endif
cp %{SOURCE3} README.SUSE

%build
pod2man -s 8 postgrey > postgrey.8
pod2man -s 8 contrib/postgreyreport > postgreyreport.8

%install
# the binaries
install -d %{buildroot}/%{_sbindir}
install -m 0755 postgrey %{buildroot}/%{_sbindir}/%{name}
install -m 0755 contrib/postgreyreport %{buildroot}/%{_sbindir}/postgreyreport
# manual
install -d %{buildroot}/%{_mandir}/man8
install -m 0644 %{name}.8 %{buildroot}%{_mandir}/man8/%{name}.8
install -m 0644 postgreyreport.8 %{buildroot}%{_mandir}/man8/postgreyreport.8
# configuration
install -d %{buildroot}/%{_sysconfdir}/%{name}
install -m 0644 postgrey_whitelist_clients %{buildroot}/%{_sysconfdir}/%{name}/whitelist_clients
install -m 0644 postgrey_whitelist_recipients %{buildroot}/%{_sysconfdir}/%{name}/whitelist_recipients
touch whitelist_clients.local
install -m 0644 whitelist_clients.local %{buildroot}/%{_sysconfdir}/%{name}
# configuration
install -D -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.%{name}
# systemd service file or init file
%if 0%{?suse_version} > 1210
install -D -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/%{name}.service
ln -s  	%{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -D %{SOURCE1} %{buildroot}%{_initddir}/%{name}
ln -sf %{_initddir}/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
# queue directory
install -d %{buildroot}/%{_localstatedir}/lib/%{name}
# directory for socket
install -d -m 0775 %{buildroot}/%{_localstatedir}/spool/postfix/%{name}

%pre
getent passwd %{name} >/dev/null || useradd -r -g nogroup -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -c "Postgrey Daemon" %{name}
%if 0%{?suse_version} > 1210
%service_add_pre %{name}.service
%endif

%preun
%if 0%{?suse_version} > 1210
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%post
%if 0%{?suse_version} > 1210
%service_add_post %{name}.service
%fillup_only
%else
%{fillup_and_insserv %{name}}
%endif

%postun
%if 0%{?suse_version} > 1210
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%doc Changes COPYING README README.SUSE
%doc examples timer
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/whitelist_recipients
%config(noreplace) %{_sysconfdir}/%{name}/whitelist_clients
%config(noreplace) %{_sysconfdir}/%{name}/whitelist_clients.local
%{_sbindir}/%{name}
%{_sbindir}/postgreyreport
%{_sbindir}/rc%{name}
%dir %attr(0755,postgrey,postfix) %{_localstatedir}/lib/%{name}
%{_fillupdir}/sysconfig.%{name}
%dir %attr(0770,postgrey,postfix) %{_localstatedir}/spool/postfix/%{name}
%doc %{_mandir}/man?/*
%if 0%{?suse_version} > 1210
%{_unitdir}/%{name}.service
%else
%config %attr(0755,root,root) %{_initddir}/%{name}
%endif

%changelog
* Tue Oct 19 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * postgrey.service
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Dec 30 2019 chris@computersalat.de
- fix for boo#1115454
  * rename  postgrey_daily_greylist.crontab
    to      postgrey_daily_greylist.sh
  * add postgrey_daily_greylist.service
    and postgrey_daily_greylist.timer
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Jun  1 2017 jengelh@inai.de
- Require group(nogroup) for %%pre
* Mon Jan 23 2017 chris@computersalat.de
- add ExecReload to service file
* Thu Oct 13 2016 draht@schaltsekun.de
- Update to 1.37:
  * added initial test suite
  * testing using travis-ci (https://travis-ci.org/schweikert/postgrey)
  * removed IP pool-detection code for --lookup-by-net, because it matched
    also the naming of some big hosters like facebook (#32, Michal Petrucha,
    Andrew Ayer, Jon Sailor)
  * fix early logging of errors and warnings to syslog
  * simplified IP matching code
  * added support for IPv6 whitelists with netmask
  * add network-range based whitelist for Office 365 (Holger Stember)
  * updated whitelist
- postgrey-1.36-config.patch renamed to postgrey-1.37-config.patch
  and rebased to new version.
* Fri May 20 2016 chris@computersalat.de
- revert process name changes from 1.35, startproc will return 7
  * add postgrey_process_name.patch
  * enable for openSUSE < 1210 (SLE_11)
* Mon May 16 2016 chris@computersalat.de
- add condition for suggesting cron to fix build for CentOS
* Sun Apr 24 2016 wr@rosenauer.org
- installing sysconfig via fillup macro was lost in systemd migration
  (boo#976963)
* Mon Dec 14 2015 benedikt.schindler@gsx.de
- update to 1.36:
  - improved support for IPv6 addresses: new --ipv4cidr and --ipv6cidr options
    for proper subnetting of IPv6 (Håvard Moen, BenediktS)
  - updated whitelist
  - user-settable unix socket permission: --socketmode (Teubel György)
  - init script fixes (Sacha Ott)
- Replace postgrey-1.35-config.patch with postgrey-1.36-config.patch
  which was updated to correctly apply to current release
- Added missing perl-NetAddr-IP to the requirements
* Mon Jan 19 2015 mpluskal@suse.com
- Replace postgrey-1.34-config.patch with postgrey-1.35-config.patch
  which was updated to correctly apply to current release
- Build as noarch since there are now architecture dependend
  components
- Don't install init scripts when systemd is used
- Create rcpostgrey also when systemd is used
- Misc spec file cleanups
- Remove unnecessary echo from unit file
- Remove condition for suggesting cron since all current releases
  already have cron
* Wed Jun 25 2014 varkoly@suse.com
- Update to 1.35 (boo #919194)
  - use just 'postgrey' as process name, instead of '/usr/sbin/postgrey', because
    Linux tools are limited to 15 characters (#5)
  - Make postgrey work with Perl 5.18 (Yasuhiro KIMURA, #4)
  - updated whitelist
* Tue Feb 11 2014 obs@botter.cc
- fix files section in spec file: submit from Nov 20 2012 removed
  two directories  (bnc#862552)
* Fri Oct  4 2013 obs@botter.cc
- fix postgre-1.34-config.path to include change of name and
  location of whitelist_recipients
* Thu Aug  8 2013 joop.boonen@opensuse.org
- Added missing perl-Net-DNS is needed for postgreyreport
* Wed May 29 2013 crrodriguez@opensuse.org
- fix multiple bugs in systemd unit file, syslog.target must
  not be used neither Requires but Wants
* Tue Nov 20 2012 lars@linux-schulserver.de
- update to 1.34:
  - gracefully handle future timestamps in the database
    (Andreas Hoedle)
  - replaced obsolete Digest::SHA1 with Digest::SHA
    (Salvatore Bonaccorso)
  - updated whitelist
- adapt patches to the new version
- adapt URL to the postgrey_clients_dump source
- specfile cleanup
- removed empty verifyscript
* Thu Nov  8 2012 obs@botter.cc
- add systemd service file for openSUSE >= 12.1
* Thu Mar 31 2011 chris@computersalat.de
- cleanup init script (skeleton)
  o added sleep 3s when restart
* Mon Jan 17 2011 coolo@novell.com
- avoid owning /var/spool/postfix directory (bnc#664537)
* Sat Aug 28 2010 bugs@singvogel.com
- version 1.33
  - fix warning with IPv6 address (Edwin Kremer)
  - added --x-greylist-header option (Guido Leisker)
  - contrib/postgrey.init: new LSB-compliant init script by
    Adrian von Bidder (Debian)
  - contrib/postgreyreport: fix POD error (Christian Perrier)
  - contrib/postgreyreport: added --tab and --show_time options
    (Leonard den Ottolander)
  - updated whitelist
* Mon Nov 30 2009 crrodriguez@opensuse.org
- refresh patches with fuzz=0
* Tue Feb  3 2009 kssingvo@suse.de
- postgrey_clients_dump is now in examples; otherwise manpage should
  be included
* Thu Aug 21 2008 kssingvo@suse.de
- fixed specfile: "Suggests:" cannot be used for SLES9
* Wed Aug 20 2008 kssingvo@suse.de
- update to version 1.32:
  * fixed recipients whitelisting
  * added --syslog-facility option
  * add support for BATV
  * updated whitelist
* Thu Apr 10 2008 kssingvo@suse.de
- added postgrey_daily_greylist.crontab script
- added postgrey_clients_dump script
* Wed Apr  2 2008 kssingvo@suse.de
- fixes for init file:
  * no pid file needed
  * sysconfig variable used after sysconfig is read
- sysconfig file:
  * fix for location of UNIX-domain socket location
- daemon:
  * no more uid postfix needed
  * using gid postfix instead (more secure?)
- run:
  * postfix subdirectory required for UNIX-domain socket location
- updated README.SUSE: a working version now
* Tue Apr  1 2008 kssingvo@suse.de
- changed init-/sysconfig-file
- updated README.SUSE
* Mon Mar 31 2008 kssingvo@suse.de
- changed system config directories to /etc/postgrey
- using own user (postgrey) for service now
- added small documenation file for SUSE distribution
* Mon Mar 31 2008 kssingvo@suse.de
- initial version 1.31
